=== modified file 'UpdateManager/Dialogs.py'
--- UpdateManager/Dialogs.py	2019-04-08 17:00:30 +0000
+++ UpdateManager/Dialogs.py	2020-04-02 00:18:15 +0000
@@ -295,6 +295,22 @@
         DistUpgradeDialog.run(self, parent)
 
 
+class NoUpgradeForYouDialog(InternalDialog):
+    def __init__(self, window_main, meta_release, arch):
+        InternalDialog.__init__(self, window_main)
+        self.set_header(_("Sorry, there are no more upgrades for this system"))
+        # Translators: this is an Ubuntu version name like "Ubuntu 12.04"
+        self.set_desc(_("\nThere will not be any further Ubuntu releases "
+                        "for this system's '%s' architecture.\n\n"
+                        "Updates for Ubuntu %s will continue until "
+                        "2023-04-26.\n\nIf you reinstall Ubuntu from "
+                        "ubuntu.com/download, future upgrades will "
+                        "be available.") %
+                        (arch, meta_release.current_dist_version))
+        self.focus_button = self.add_button(Gtk.STOCK_OK,
+                                            self.window_main.close)
+
+
 class PartialUpgradeDialog(InternalDialog):
     def __init__(self, window_main):
         InternalDialog.__init__(self, window_main)

=== modified file 'UpdateManager/UpdateManager.py'
--- UpdateManager/UpdateManager.py	2019-04-08 17:00:30 +0000
+++ UpdateManager/UpdateManager.py	2020-04-02 00:18:15 +0000
@@ -52,6 +52,7 @@
                       HWEUpgradeDialog,
                       NeedRestartDialog,
                       NoUpdatesDialog,
+                      NoUpgradeForYouDialog,
                       PartialUpgradeDialog,
                       StoppedUpdatesDialog,
                       UnsupportedDialog,
@@ -62,7 +63,7 @@
 from .Core.MyCache import MyCache
 from .Core.roam import NetworkManagerHelper
 from .Core.UpdateList import UpdateList
-from .Core.utils import get_dist
+from .Core.utils import get_arch, get_dist
 from .backend import (InstallBackend,
                       get_backend)
 
@@ -86,6 +87,7 @@
         self.update_list = None
         self.meta_release = None
         self.hwe_replacement_packages = None
+        self.arch = get_arch()
 
         # Basic GTK+ parameters
         self.set_title(_("Software Updater"))
@@ -307,6 +309,9 @@
         if (self.meta_release.new_dist
                 and (self.options.check_dist_upgrades
                      or settings.get_boolean("check-dist-upgrades"))):
+            if self.arch == 'i386':
+                return NoUpgradeForYouDialog(self, self.meta_release,
+                                             self.arch)
             return DistUpgradeDialog(self, self.meta_release)
 
         return None

=== modified file 'debian/changelog'
--- debian/changelog	2020-01-31 21:44:36 +0000
+++ debian/changelog	2020-04-02 00:18:15 +0000
@@ -1,3 +1,10 @@
+update-manager (1:20.04.2) UNRELEASED; urgency=medium
+
+  * UpdateManager/UpdateManager.py: Do not offer to upgrade systems running on
+    an i386 host architecture to another release. (LP: #1845690)
+
+ -- Brian Murray <brian@ubuntu.com>  Wed, 01 Apr 2020 17:15:59 -0700
+
 update-manager (1:20.04.1) focal; urgency=medium
 
   * UpdateManager/Core/UpdateList.py: remove unused import of subprocess.

